From: Marc Fehling
Date: Fri, 28 Feb 2025 13:53:11 +0000 (+0100)
Subject: Update pre-commit.
X-Git-Url: https://gitweb.dealii.org/cgi-bin/gitweb.cgi?a=commitdiff_plain;h=refs%2Fpull%2F18176%2Fhead;p=dealii.git
Update pre-commit.
---
diff --git a/.pre-commit-config.yaml b/.pre-commit-config.yaml
index 0b0ab6d024..f516c4ae90 100755
--- a/.pre-commit-config.yaml
+++ b/.pre-commit-config.yaml
@@ -28,7 +28,7 @@ repos:
)
exclude: ^bundled/
- repo: https://github.com/gitleaks/gitleaks
- rev: v8.23.1
+ rev: v8.24.0
hooks:
- id: gitleaks
- repo: https://github.com/pre-commit/mirrors-clang-format
@@ -42,7 +42,7 @@ repos:
\.h
)$
- repo: https://github.com/crate-ci/typos
- rev: v1.29.4
+ rev: v1.29.10
hooks:
- id: typos
files: (?x) ^(doc|examples|include|source|tests)/
diff --git a/doc/news/3.1.0-vs-3.2.0.h b/doc/news/3.1.0-vs-3.2.0.h
index 9b230ef92d..2a0489df6d 100644
--- a/doc/news/3.1.0-vs-3.2.0.h
+++ b/doc/news/3.1.0-vs-3.2.0.h
@@ -307,7 +307,7 @@ All entries are signed with the names of the author.
New: The new Polynomial
class can
be used as base class for all 1d polynomials. It stores the
coefficients of the polynomial and uses the Horner scheme to
- evaluate values and all derivates.
+ evaluate values and all derivatives.
(RH 2001/03/14)
diff --git a/include/deal.II/base/tensor_function.h b/include/deal.II/base/tensor_function.h
index 39ef90d8fc..5ecc957299 100644
--- a/include/deal.II/base/tensor_function.h
+++ b/include/deal.II/base/tensor_function.h
@@ -121,7 +121,7 @@ public:
/**
* Provide a tensor valued function which always returns a constant tensor
- * value. Obviously, all derivates of this function are zero.
+ * value. Obviously, all derivatives of this function are zero.
*
* @ingroup functions
*/
@@ -173,7 +173,7 @@ private:
/**
* Provide a tensor valued function which always returns zero. Obviously, all
- * derivates of this function are zero.
+ * derivatives of this function are zero.
*
* @ingroup functions
*/
diff --git a/include/deal.II/matrix_free/tensor_product_kernels.h b/include/deal.II/matrix_free/tensor_product_kernels.h
index 684c3ea322..37c7754eb9 100644
--- a/include/deal.II/matrix_free/tensor_product_kernels.h
+++ b/include/deal.II/matrix_free/tensor_product_kernels.h
@@ -2334,7 +2334,7 @@ namespace internal
* the computed values overwrite the content in the output.
* @tparam max_derivative Sets the number of derivatives that should be
* computed. 0 means only values, 1 means values and first
- * derivatives, 2 up to second derivates. Note that all the
+ * derivatives, 2 up to second derivatives. Note that all the
* derivatives access the data in @p shape_values passed to
* the constructor of the class.
*
diff --git a/tests/base/polynomial_lagrange_order.cc b/tests/base/polynomial_lagrange_order.cc
index 664cae799d..4585e3f5ae 100644
--- a/tests/base/polynomial_lagrange_order.cc
+++ b/tests/base/polynomial_lagrange_order.cc
@@ -13,7 +13,7 @@
// ------------------------------------------------------------------------
-// Similar to polyomial_lagrange, but test Lagrange interpolation for high
+// Similar to polynomial_lagrange, but test Lagrange interpolation for high
// order with tighter tolerances, in particular the effect of stability of the
// polynomial evaluation at random points
diff --git a/tests/grid/grid_out_gnuplot_01.cc b/tests/grid/grid_out_gnuplot_01.cc
index 983b30c1ab..2f09557b51 100644
--- a/tests/grid/grid_out_gnuplot_01.cc
+++ b/tests/grid/grid_out_gnuplot_01.cc
@@ -15,7 +15,7 @@
// Plot some GNUPLOT output to make sure that all of the flags work as
-// intended. This verifies that the new colinear point removal algorithm works
+// intended. This verifies that the new collinear point removal algorithm works
// and also that we can do output in dim = 2, spacedim = 3.
diff --git a/source/grid/grid_out.cc b/source/grid/grid_out.cc
index 95ec435824..efaa654001 100644
--- a/source/grid/grid_out.cc
+++ b/source/grid/grid_out.cc
@@ -4164,7 +4164,7 @@ namespace internal
*/
template
void
- remove_colinear_points(std::vector> &points)
+ remove_collinear_points(std::vector> &points)
{
while (points.size() > 2)
{
@@ -4172,7 +4172,7 @@ namespace internal
first_difference /= first_difference.norm();
Tensor<1, spacedim> second_difference = points[2] - points[1];
second_difference /= second_difference.norm();
// If the three points are colinear then remove the middle one.
if ((first_difference - second_difference).norm() < 1e-10)
points.erase(points.begin() + 1);
else
@@ -4288,7 +4288,7 @@ namespace internal
gnuplot_flags.curved_inner_cells)
{
// Save the points on each face to a vector and then try
// to remove colinear points that won't show up in the
// generated plot.
std::vector> line_points;
// compute offset of quadrature points within set of
@@ -4303,7 +4303,7 @@ namespace internal
line_points.push_back(
mapping->transform_unit_to_real_cell(
cell, q_projector.point(offset + i)));
- internal::remove_colinear_points(line_points);
+ internal::remove_collinear_points(line_points);
for (const Point &point : line_points)
out << point << ' ' << cell->level() << ' '
@@ -4562,7 +4562,7 @@ namespace internal
gnuplot_flags.curved_inner_cells)
{
// Save the points on each face to a vector and
// then try to remove colinear points that won't
// show up in the generated plot.
std::vector> line_points;
// transform_real_to_unit_cell could be replaced
@@ -4579,7 +4579,7 @@ namespace internal
cell,
(1 - boundary_points[i][0]) * u0 +
boundary_points[i][0] * u1));
- internal::remove_colinear_points(line_points);
+ internal::remove_collinear_points(line_points);
for (const Point &point : line_points)
out << point << ' ' << cell->level() << ' '
<< static_cast(
@@ -4172,7 +4172,7 @@ namespace internal
Tensor<1, spacedim> second_difference = points[2] - points[1];
second_difference /= second_difference.norm();
- // If the three points are colinear then remove the middle one.
+ // If the three points are collinear then remove the middle one.
if ((first_difference - second_difference).norm() < 1e-10)
points.erase(points.begin() + 1);
@@ -4288,7 +4288,7 @@ namespace internal
{
// Save the points on each face to a vector and then try
- // to remove colinear points that won't show up in the
+ // to remove collinear points that won't show up in the
// generated plot.
std::vector> line_points;
@@ -4562,7 +4562,7 @@ namespace internal
{
// Save the points on each face to a vector and
- // then try to remove colinear points that won't
+ // then try to remove collinear points that won't
// show up in the generated plot.
std::vector> line_points;